@@ -34,7 +34,7 @@ def brightness(hex_color, pct_change):
     return rgb_to_hex(r_, g_, b_)
 
 
-class BootStyle(ttk.Style):
+class Style(ttk.Style):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.themes = {}
